@@ -844,7 +844,7 @@ valid_pci_options(struct options *opts)
 	}
 
 	/* The -s option can specify a drc name or drc index */
-	if (!strncmp(opts->usr_drc_name, "0x", 2)) {
+	if (opts->usr_drc_name && !strncmp(opts->usr_drc_name, "0x", 2)) {
 		opts->usr_drc_index = strtoul(opts->usr_drc_name, NULL, 16);
 		opts->usr_drc_name = NULL;
 	}
@@ -855,8 +855,8 @@ valid_pci_options(struct options *opts)
 	}
 
 	if ((opts->action != ADD) && (opts->action != REMOVE)
-	    && (opts->action != IDENTIFY)) {
-		say(ERROR, "The '-r', '-a', or '-i' option must be spcified "
+	    && (opts->action != IDENTIFY) && (opts->action != REPLACE)) {
+		say(ERROR, "The '-r', '-a', '-R' or '-i' option must be spcified "
 	 	    "for PCI operations\n");
 		return -1;
 	}
