@@ -113,7 +113,8 @@ help(void)
     "  --nvram-file <path>\n"
     "          specify alternate nvram data file (default is /dev/nvram)\n"
     "  --nvram-size\n"
-    "          specify size of nvram data (for repair operations)\n"
+    "          specify size of nvram data, must in multiples of 16 Bytes\n"
+    "          (for repair operations)\n"
     "  --verbose (-v)\n"
     "          be (more) verbose\n"
     "  --help\n"
@@ -205,17 +206,18 @@ warn_msg(const char *fmt, ...)
 int 
 nvram_read(struct nvram *nvram)
 {
-    int len, remaining;
+    int len, remaining, chunk;
     char *p;
 
     /* read in small chunks */
-    for (p = nvram->data, remaining = nvram->nbytes;
-           (len = read(nvram->fd, p, 512)) > 0;
-           p += len, remaining -= len) {
-           if (remaining <= 0) {
-               remaining = 0;
-               break;
-           }
+    p = nvram->data;
+    remaining = nvram->nbytes;
+    chunk = (NVRAM_READ_SIZE < remaining) ? NVRAM_READ_SIZE : remaining;
+
+    while ((len = read(nvram->fd, p, chunk)) > 0) {
+        p+=len;
+        remaining -= len;
+        chunk = (NVRAM_READ_SIZE < remaining) ? NVRAM_READ_SIZE : remaining;
     }
 
     if (len == -1) {
@@ -1111,7 +1113,7 @@ unzip_partition(struct nvram *nvram, char *name)
     start = (char*) phead;
     next = start + sizeof(*phead);	/* Skip partition header. */
     next += sizeof(struct err_log_info);	/* Skip sub-header. */
-    zipped_length = *((unsigned short*) next);
+    zipped_length = be16toh(*((unsigned short*) next));
     next += sizeof(unsigned short);
 
    /* New format oops header, zipped_length > OOPS_PARTITION_SZ
@@ -1119,7 +1121,7 @@ unzip_partition(struct nvram *nvram, char *name)
     * and from where the compressed data starts.
     */
    if (zipped_length > OOPS_PARTITION_SZ) {
-        zipped_length = *((unsigned short*) next);
+        zipped_length = be16toh(*((unsigned short*) next));
         next += sizeof(struct oops_log_info) - sizeof(unsigned short);
    }
 
@@ -1485,6 +1487,10 @@ main (int argc, char *argv[])
 		    err_msg("specify nvram-size as an integer\n");
 		    exit(1);
 		}
+		if (nvram.nbytes % NVRAM_BLOCK_SIZE) {
+		    err_msg("nvram-size must be a multiple of 16 Bytes\n");
+		    exit(1);
+		}
 		break;
 	    case 'V':	/* print-vpd */
 		print_vpd = 1;
