@@ -10,10 +10,10 @@
 #define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <unistd.h>
 #include <string.h>
 #include <dirent.h>
-#include <librtas.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -25,10 +25,16 @@
 #include <sys/ptrace.h>
 #include <sys/wait.h>
 #include <sys/resource.h>
+
+#ifdef WITH_LIBRTAS
+#include <librtas.h>
+#include "librtas_error.h"
+#endif
+
 #ifdef HAVE_LINUX_PERF_EVENT_H
 #include <linux/perf_event.h>
 #endif
-#include "librtas_error.h"
+
 #include <errno.h>
 
 #define PPC64_CPU_VERSION	"1.2"
@@ -504,8 +510,6 @@ static int do_smt(char *state)
 
 		if (smt_state == 1)
 			printf("SMT is off\n");
-		else if (smt_state == threads_per_cpu)
-			printf("SMT is on\n");
 		else if (smt_state == -1)
 			printf("Inconsistent state: mix of ST and SMT cores\n");
 		else
@@ -682,6 +686,8 @@ static int do_smt_snooze_delay(char *state)
 	return rc;
 }
 
+#ifdef WITH_LIBRTAS
+
 static int do_run_mode(char *run_mode)
 {
 	char mode[3];
@@ -744,6 +750,16 @@ static int do_run_mode(char *run_mode)
 	return rc;
 }
 
+#else
+
+static int do_run_mode(char *run_mode)
+{
+	printf("Run mode determination is not supported on this platfom.\n");
+	return -1;
+}
+
+#endif
+
 #ifdef HAVE_LINUX_PERF_EVENT_H
 
 static int setup_counters(void)
